@@ -10,6 +10,59 @@ class Settings_Editor(object):
     Class that manage all the parameters needed to
     generate the configuration file (setting.conf) for the engine.
     The configuration file path need to be specified.
+
+    Parameters:
+    ==========
+        file_path: str
+            The string of the configuration file path.
+
+    Available Configurations:
+    ------------------------
+        'file_path'
+        'dataset_path'
+        'results_foldername'
+        'algorithm'
+        'topN'
+        'k_folds'
+        'random_seed'
+        'num_factors'
+        'num_max_iterations'
+        'learning_rate'
+        'reg_lambda'
+        'num_neighboors'
+        'similarity'
+
+    Available algorithms:
+    --------------------
+        "itemknn"
+        "userknn"
+        "slopeone"
+        "pmf"
+        "bpmf"
+        "biasedmf"
+        "nmf"
+        "svd++"
+        "usersplitting"
+        "itemsplitting"
+        "uisplitting"
+        "spf"
+        "dcr"
+        "dcw"
+        "cptf"
+        "camf_ci"
+        "camf_cu"
+        "camf_cuci"
+        "cslim_ci"
+        "cslim_cu"
+        "cslim_cuci"
+        "gcslim_cc"
+        "cslim_ics"
+        "cslim_lcs"
+        "cslim_mcs"
+        "gcslim_ics"
+        "gcslim_lcs"
+        "gcslim_mcs"
+
     """
 
     def __init__(self, file_path: str):
@@ -19,10 +72,7 @@ class Settings_Editor(object):
 
         # self.db = pickledb.load("./carskit_api/settings_data.json", True)
         self.db = pickledb.load(
-            os.path.join(
-                pl.Path(self.file_path).parent,
-                "settings_data.json"),
-            True
+            os.path.join(pl.Path(self.file_path).parent, "settings_data.json"), True
         )
 
         self.__dataset_path = "None"
@@ -33,7 +83,6 @@ class Settings_Editor(object):
         self.__results_foldername = "results"
 
         self.__algorithm = "camf_cu"
-
         """
         Para as configurações de algoritmos específicos talvez seja necessário o uso de expressões regulares
         """
@@ -82,7 +131,7 @@ class Settings_Editor(object):
             "cslim_mcs",
             "gcslim_ics",
             "gcslim_lcs",
-            "gcslim_mcs"
+            "gcslim_mcs",
         ]
 
         if not self.db.get("parameters"):
@@ -93,6 +142,15 @@ class Settings_Editor(object):
         """
         Define and validate the path to the dataset that is going
         to be used and returns a message about the operation's success.
+
+        Parameters:
+        ==========
+            path: str
+                The path for the txt or csv dataset file
+
+        Returns:
+        -------
+            str: The dataset path, if the operation the was successfull, or a error message if not.
         """
 
         if isinstance(path, str) and os.path.exists(path):
@@ -109,13 +167,25 @@ class Settings_Editor(object):
         """
         Define and validate the name for the results that the engine will generate
         and returns a message about the operation's success.
-        """
-        if isinstance(name, str):
-            self.__results_foldername = name
-            self.__parameters["results_foldername"] = self.__results_foldername
 
-            return self.__results_foldername
-        return "ERROR! Path Invalid."
+        Parameters:
+        ----------
+            name: str
+                The folder name where the engine will create the reccomendations.
+
+        Returns:
+        -------
+            str: The folder name, if the operation the was successfull, or a error message if not.
+        """
+        if isinstance(name, str) and not str(name).isdigit():
+            if name != "":
+                self.__results_foldername = name
+                self.__parameters["results_foldername"] = self.__results_foldername
+
+                return self.__results_foldername
+            else:
+                return "ERROR! The name is empty."
+        return "ERROR! Name Invalid."
 
     def get_results_foldername(self) -> str:
         return self.__results_foldername
@@ -124,6 +194,15 @@ class Settings_Editor(object):
         """
         Define and validate the algorithm that is going
         to be used and returns a message about the operation's success.
+
+        Parameters:
+        ----------
+            algo: str
+                The algorithm's name that will be used in the next engine's execution.
+
+        Returns:
+        -------
+            str: The algorithm's name, if the operation the was successfull, or a error message if not.
         """
 
         if isinstance(algo, str) and algo != "":
@@ -141,7 +220,19 @@ class Settings_Editor(object):
         """
         Define and validate a parameter for the next engine's execution
         and returns a message about the operation's success.
+
+        Parameters:
+        ----------
+            key: str
+                The parameter's name that will be changed.
+            value: str
+                The new value for the parameter specified.
+
+        Returns:
+        -------
+            str: The new value, if the operation the was successfull, or a error message if not.
         """
+
         if key == "dataset_path":
             return self.set_dataset_path(value)
         elif key == "results_foldername":
@@ -197,7 +288,7 @@ class Settings_Editor(object):
 
         if not os.path.exists(self.file_path):
             return "ERROR! Settings file's path do not exist!"
-        if self.__dataset_path == "":
+        if self.__dataset_path == "None":
             return "ERROR! No dataset selected!"
 
         try:
@@ -271,21 +362,16 @@ class Settings_Editor(object):
                 "GCSLIM_ICS=-lw1 1 -lw2 5 -k 10 -als 0\n",
                 "GCSLIM_LCS=-lw1 1 -lw2 5 -k -1 -als 0\n",
                 "GCSLIM_MCS=-lw1 1 -lw2 5 -k -1 -als 0\n",
-                "FM=-lw 0.01 -lf 0.02\n"
+                "FM=-lw 0.01 -lf 0.02\n",
             ]
             for i in range(len(settings_str)):
                 settings_file.write(settings_str[i])
 
             settings_file.close()
-            # print("#########")
-            # print(f"File name: { os.path.basename(self.file_path) }")
-            # print("#########")
             return "The settings file was generated!"
         else:
             return "ERROR! The file is not readable!"
 
     def __del__(self):
-        """
-        Saves the settings when the class is dealocated.
-        """
+        """Saves the settings when the class is dealocated."""
         self.save_settings()
