@@ -6,6 +6,11 @@ class Runner(object):
     """
     Class that runs the CARSKit java file.
     It is only need the complete or relative path to the file to run it.
+
+    Parameters:
+    ----------
+        javaFile_path: str
+            The path for the folder where the engine's java file is.
     """
 
     def __init__(self, javaFile_path: str):
@@ -18,6 +23,7 @@ class Runner(object):
         """
         os.chdir(self.javaFile_path)
         output = subprocess.call(
-            ['java', '-jar', 'CARSKit-v0.3.5.jar', '-c', 'setting.conf'])
+            ["java", "-jar", "CARSKit-v0.3.5.jar", "-c", "setting.conf"]
+        )
         os.chdir(self.current_path)
         return output
